FrameSocket

Struct FrameSocket 

pub struct FrameSocket<T> { /* private fields */ }
Read buffer size used for FrameSocket.

Implementations

Source

impl<T: Read + Write> FrameSocket<T>

pub fn new(stream: T) -> Self

Create a new frame socket.

pub fn from_partially_read(stream: T, part: Vec<u8>) -> Self

Create a new frame socket from partially read data.

pub fn into_inner(self) -> (T, BytesMut)

Extract a stream from the socket.

pub fn get_ref(&self) -> &T

Returns a shared reference to the inner stream.

pub fn get_mut(&mut self) -> &mut T

Returns a mutable reference to the inner stream.

pub fn read(&mut self, max: Option<usize>) -> Result<Option<Frame>>

Read a frame from stream.

pub fn send(&mut self, frame: Frame) -> Result<()>

Writes and immediately flushes a frame. Equivalent to calling write then flush.

pub fn write(&mut self, frame: Frame) -> Result<()>

Write a frame to stream.

A subsequent call should be made to flush to flush writes.

This function guarantees that the frame is queued unless Error::WriteBufferFull is returned. In order to handle WouldBlock or Incomplete, call flush afterwards.

pub fn flush(&mut self) -> Result<()>

Flush writes.