Message

Enum Message 

pub enum Message {
    Text(Utf8Bytes),
    Binary(Bytes),
    Ping(Bytes),
    Pong(Bytes),
    Close(Option<CloseFrame>),
    Frame(Frame),
}
A WebSocket message

Variants



Text(Utf8Bytes)

A text message



Binary(Bytes)

A binary message



Ping(Bytes)

A ping (control) message



Pong(Bytes)

A pong (control) message



Close(Option<CloseFrame>)

A close (control) message



Frame(Frame)

Raw frame

Implementations

Source

impl Message

pub fn new_text<S>(string: S) -> Message
where S: Into<Utf8Bytes>,

Create a new text WebSocket message from a stringable.

pub fn new_binary<B>(binary: B) -> Message
where B: Into<Bytes>,

Create a new binary WebSocket message by converting to Bytes.

pub fn is_control(&self) -> bool

Indicates if the Message is of control protocol (Ping, Pong, Close)

pub fn is_data(&self) -> bool

Indicates if the Message is of data protocol (Text, Binary)

pub fn is_text(&self) -> bool

Indicates if the Message is of Text protocol

pub fn is_binary(&self) -> bool

Indicates if the Message is of Binary protocol

pub fn len(&self) -> usize

Get the length of the WebSocket message.

pub fn is_empty(&self) -> bool

Returns true if the WebSocket message has no content. For example, if the other side of the connection sent an empty string.

pub fn into_data(self) -> Bytes

Parses the message data