pub struct WebSocket<T> { /* private fields */ }Expand description
WebSocket input-output stream.
This is THE structure you want to create to be able to speak the WebSocket protocol.
It may be created by calling connect, accept or client functions.
Use WebSocket::read, WebSocket::send to received and send messages.
Implementations
Sourceimpl<T: Read + Write> WebSocket<T>
impl<T: Read + Write> WebSocket<T>
Sourcepub fn new(
stream: T,
mode: OperationMode,
config: Option<WebSocketConfig>,
) -> Self
pub fn new( stream: T, mode: OperationMode, config: Option<WebSocketConfig>, ) -> Self
Convert a raw socket into a WebSocket without performing a handshake.
Call this function if you’re using Tungstenite as a part of a web framework
or together with an existing one. If you need an initial handshake, use
connect() or accept() functions of the crate to construct a websocket.
Panics
Panics if config is invalid e.g. max_write_buffer_size <= write_buffer_size.
Sourcepub fn from_partially_read(
stream: T,
part: Vec<u8>,
mode: OperationMode,
config: Option<WebSocketConfig>,
) -> Self
pub fn from_partially_read( stream: T, part: Vec<u8>, mode: OperationMode, config: Option<WebSocketConfig>, ) -> Self
Convert a raw socket into a WebSocket without performing a handshake.
Call this function if you’re using Tungstenite as a part of a web framework
or together with an existing one. If you need an initial handshake, use
connect() or accept() functions of the crate to construct a websocket.
Panics
Panics if config is invalid e.g. max_write_buffer_size <= write_buffer_size.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Returns the inner instance of the stream
Sourcepub fn set_config(&mut self, func: impl FnOnce(&mut WebSocketConfig))
pub fn set_config(&mut self, func: impl FnOnce(&mut WebSocketConfig))
Change the configuration.
Panics
Panics if config is invalid e.g. max_write_buffer_size <= write_buffer_size.
Sourcepub fn get_config(&self) -> &WebSocketConfig
pub fn get_config(&self) -> &WebSocketConfig
Read the configuration.
Sourcepub fn can_read(&self) -> bool
pub fn can_read(&self) -> bool
Check if it is possible to read messages.
Reading is impossible after receiving Message::Close. It is still possible after
sending close frame since the peer still may send some data before confirming close.
Sourcepub fn can_write(&self) -> bool
pub fn can_write(&self) -> bool
Check if it is possible to write messages.
Writing gets impossible immediately after sending or receiving Message::Close.
Sourcepub fn read(&mut self) -> Result<Message>
pub fn read(&mut self) -> Result<Message>
Check if it is possible to read messages.
Reading is impossible after receiving Message::Close. It is still possible after
sending close frame since the peer still may send some data before confirming close.
Sourcepub fn write(&mut self, msg: Message) -> Result<()>
pub fn write(&mut self, msg: Message) -> Result<()>
Write a message to the provided stream, if possible.
A subsequent call should be made to flush to flush writes.
In the event of stream write failure the message frame will be stored
in the write buffer and will try again on the next call to write
or flush.
If the write buffer would exceed the configured WebSocketConfig::max_write_buffer_size
Err(WriteBufferFull(msg_frame)) is returned.
This call will generally not flush. However, if there are queued automatic messages they will be written and eagerly flushed.
For example, upon receiving ping messages tungstenite queues pong replies automatically.
The next call to read, write or flush
will write & flush the pong reply. This means you should not respond to ping frames manually.
You can however send pong frames manually in order to indicate a unidirectional heartbeat
as described in RFC 6455. Note that
if read returns a ping, you should flush before passing
a custom pong to write, otherwise the automatic queued response to the
ping will not be sent as it will be replaced by your custom pong message.
Errors
- If the WebSocket’s write buffer is full,
Error::WriteBufferFullwill be returned along with the equivalent passed message frame. - If the connection is closed and should be dropped, this will return
Error::ConnectionClosed. - If you try again after
Error::ConnectionClosedwas returned either from here or fromread,Error::AlreadyClosedwill be returned. This indicates a program error on your part. Error::Iois returned if the underlying connection returns an error (consider these fatal except for WouldBlock).Error::Capacityif your message size is bigger than the configured max message size.
Sourcepub fn flush(&mut self) -> Result<()>
pub fn flush(&mut self) -> Result<()>
Flush writes.
Ensures all messages previously passed to write and automatic
queued pong responses are written & flushed into the underlying stream.
Sourcepub fn close(&mut self, code: Option<CloseFrame>) -> Result<()>
pub fn close(&mut self, code: Option<CloseFrame>) -> Result<()>
Close the connection.
This function guarantees that the close frame will be queued.
There is no need to call it again. Calling this function is
the same as calling write(Message::Close(..)).
After queuing the close frame you should continue calling read or
flush to drive the close handshake to completion.
The websocket RFC defines that the underlying connection should be closed by the server. Tungstenite takes care of this asymmetry for you.
When the close handshake is finished (we have both sent and received
a close message), read or flush will return
Error::ConnectionClosed if this endpoint is the server.
If this endpoint is a client, Error::ConnectionClosed will only be returned after the server has closed the underlying connection.
It is thus safe to drop the underlying connection as soon as Error::ConnectionClosed
is returned from read or flush.