Blitz: Lightweight WebSocket + HTTP server components
Re-exports
pub use crate::client::client;pub use crate::client::connect;pub use crate::client::ClientRequestBuilder;pub use crate::handshake::client::ClientHandshake;pub use crate::handshake::server::ServerHandshake;pub use crate::handshake::HandshakeError;pub use http;
Modules
- buffer
- A buffer for reading data from the network.
- client
- Utilities to connect to a WebSocket as a client
- error
- Error handling
- handshake
- Handshake module
- protocol
- Protocol module
- stream
- Convenience wrapper for streams to switch between plain TCP and TLS at runtime.
- util
- Helper traits to ease non-blocking handling.
Structs
- Bytes
- A cheaply cloneable and sliceable chunk of contiguous memory.
Enums
- Connector
- A connector that can be used when establishing connections, allowing to control whether
native-tlsorrustlsis used to create a TLS connection. Or TLS can be disabled with thePlainvariant.
Constants
- MAX_
ALLOWED_ LEN - Constant for maximum message payload length
- MAX_
CONTINUATION_ FRAMES - Constant for maximum continuation frames
- MAX_
CONTROL_ FRAME_ PAYLOAD - Constant for maximum control frame payload size
Functions
- accept
- Accept the given Stream as a WebSocket.
- accept_
header - Accept the given Stream as a WebSocket.
- accept_
header_ with_ config - Accept the given Stream as a WebSocket.
- accept_
with_ config - Accept the given Stream as a WebSocket.
- client_
tls - Creates a WebSocket handshake from a request and a stream, upgrading the stream to TLS if required.
- client_
tls_ with_ config - The same as
client_tls()but one can specify a websocket configuration, and an optional connector. If no connector is specified, a default one will be created.